@@ -87,12 +87,10 @@ class OrderingInlineModelFormField(InlineModelFormField):
         return field == self.position_field
 
     def process(self, formdata, data=None):
-        print formdata
         res = super(OrderingInlineModelFormField, self).process(formdata, data)
         for f in self.form:
             if isinstance(f, PositionField):
                 self.position_field = f
-                print self.form, f.id, data
                 if data:
                     f.choices = [(i, i) for i in range(1, self.size_list+1)]
                 else:
